import { ICreateUsersDTO } from "@modules/users/dtos/ICreateUserDTO";
import { IUpdateUsersDTO } from "@modules/users/dtos/IUpdateUserDTO";
import { User } from "@prisma/client";
import prismaClient from "@shared/infra/prisma";
import { IUsersRepository } from "../IUsersRepostory";

class UserRepository implements IUsersRepository {
    async create({ name, email, password, cpf, curriculo }: ICreateUsersDTO): Promise<User> {
        const user = await prismaClient.user.create({
            data: {
                name,
                email,
                password,
                cpf,
                curriculo
            }
        })
        return user
    }
    
    async findByEmail(email: string): Promise<User> {
        const user = await prismaClient.user.findUnique({
            where: {email}
        })

        return user as User
    }

    async findAllUser(): Promise<User[]> {
        const users = await prismaClient.user.findMany()
        return users;
    }

    async deleteUser(id: string): Promise<Boolean> {
        await prismaClient.user.delete({
            where: {id}
        })

        return true
    }

    async findById(id: string): Promise<User> {
        const user = await prismaClient.user.findUnique({
            where: {id}
        })

        return user as User;
    }

    async findByCPF(cpf: string): Promise<User> {
        const user = await prismaClient.user.findFirst({
            where: {cpf}
        })

        return user as User
    }

    async update({ id, name, email, password, cpf, curriculo }: IUpdateUsersDTO): Promise<User> {
        const user = await prismaClient.user.update({
            where: {id},
            data: {
                name,
                email,
                password,
                cpf,
                curriculo
            }
        })

        return user
    }
}

export { UserRepository };